geessbin_all provides analysis results using all combinations of three
GEE methods and 12 covariance estimators.
geessbin_all(
formula,
data = parent.frame(),
id = NULL,
corstr = "independence",
repeated = NULL,
b = NULL,
maxitr = 50,
tol = 1e-05,
scale.fix = FALSE,
conf.level = 0.95
)The list containing two data frames. The first is a table of estimates of regression coefficients, standard errors, z-values, and p-values. The second is a table of odds ratios and confidence intervals.
Object of class formula: symbolic description of model to be
fitted (see documentation of lm and
formula for details).
Data frame.
Vector that identifies the subjects or clusters (NULL by
default).
Working correlation structure. The following are permitted:
"independence", "exchangeable", "ar1", and
"unstructured" ("independence" by default).
Vector that identifies repeatedly measured variable within
each subject or cluster. If repeated = NULL, as is the case in
function gee, data are assumed to be sorted so that
observations on a cluster are contiguous rows for all entities
in the formula.
Numeric vector specifying initial values of regression coefficients.
If b = NULL (default value), the initial values are calculated
using the ordinary or Firth logistic regression assuming that all the
observations are independent.
Maximum number of iterations (50 by default).
Tolerance used in fitting algorithm (1e-5 by default).
Logical variable; if TRUE, the scale parameter is
fixed at 1 (FALSE by default).
Numeric value of confidence level for confidence intervals (0.95 by default).